# vim:fenc=utf-8
#
# Copyright (C) 2023 dbpunk.com Author imotai <codego.me@gmail.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from rich.markdown import TextElement, Markdown
from rich.syntax import Syntax
from rich.console import Console, ConsoleOptions, RenderResult
from markdown_it.token import Token


class CodeBlock(TextElement):
    """A code block with syntax highlighting."""

    style_name = "markdown.code_block"

    @classmethod
    def create(cls, markdown: "Markdown", token: Token) -> "CodeBlock":
        node_info = token.info or ""
        lexer_name = node_info.partition(" ")[0]
        return cls(lexer_name or "default", markdown.code_theme)

    def __init__(self, lexer_name: str, theme: str) -> None:
        self.lexer_name = lexer_name
        self.theme = theme

    def __rich_console__(
        self, console: Console, options: ConsoleOptions
    ) -> RenderResult:
        code = str(self.text).rstrip()
        syntax = Syntax(
            code,
            self.lexer_name,
            # background_color="default",
            line_numbers=True,
            theme=self.theme,
            word_wrap=True,
            padding=1,
        )
        yield syntax



# vim:fenc=utf-8
#
# Copyright (C) 2023 dbpunk.com Author imotai <codego.me@gmail.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

""" """
from setuptools import setup, find_packages

setup(
    name="octopus_chat",
    version="0.4.3",
    description="the chat client for open source code interpreter octopus",
    author="imotai",
    author_email="wangtaize@dbpunk.com",
    url="https://github.com/dbpunk-labs/octopus",
    long_description= open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=[
        "octopus_discord",
        "octopus_terminal",
    ],
    package_dir={
        "octopus_discord": "src/octopus_discord",
        "octopus_terminal": "src/octopus_terminal",
    },
    install_requires=[
        "octopus_agent>=0.1.0",
        "rich>=13.5.2",
        "prompt_toolkit>=3.0.0",
        "click>=8.0.0",
        "discord.py>=2.3.2",
        "clipboard>=0.0.4",
        "Pillow",
        "term-image>=0.7.0",
    ],
    entry_points={
        "console_scripts": [
            "octopus = octopus_terminal.terminal_chat:app",
            "octopus_ping = octopus_terminal.ping:app",
            "octopus_discord_bot = octopus_discord.discord_chat:run_app",
        ]
    },
)



# vim:fenc=utf-8
#
# Copyright (C) 2023 dbpunk.com Author imotai <codego.me@gmail.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

""" """
import sys
import os
import click
from octopus_agent.agent_sdk import AgentSyncSDK
from rich.console import Console
from dotenv import dotenv_values


@click.command()
@click.option("--octopus_dir", default="~/.octopus", help="the root path of octopus")
def app(octopus_dir):
    console = Console()
    if octopus_dir.find("~") == 0:
        real_octopus_dir = octopus_dir.replace("~", os.path.expanduser("~"))
    else:
        real_octopus_dir = octopus_dir
    if not os.path.exists(real_octopus_dir):
        os.mkdir(real_octopus_dir)
    octopus_config = dotenv_values(real_octopus_dir + "/config")
    console = Console()
    try:
        if "api_key" not in octopus_config or "endpoint" not in octopus_config:
            console.print(
                f"❌ api key and endpoint are required! please check your config {octopus_dir}/config"
            )
            sys.exit(1)
        sdk = AgentSyncSDK(octopus_config["endpoint"], octopus_config["api_key"])
        sdk.connect()
        response = sdk.ping()
        if response.code == 0:
            console.print(f"👍 {response.msg}")
            sys.exit(0)
        else:
            console.print(f"❌ {response.msg}")
            sys.exit(1)
    except Exception as ex:
        console.print(
            f"❌ please check your config {octopus_dir}/config with error {ex}"
        )
